Info<< "Reading field p\n" << endl;
volScalarField p
(
    IOobject
    (
        "p",
        runTime.timeName(),
        mesh,
        IOobject::MUST_READ,
        IOobject::AUTO_WRITE
    ),
    mesh
);

Info<< "Reading field U\n" << endl;
volVectorField U
(
    IOobject
    (
        "U",
        runTime.timeName(),
        mesh,
        IOobject::MUST_READ,
        IOobject::AUTO_WRITE
    ),
    mesh
);

volSymmTensorField tau
(
        IOobject
        (
            "tau",
            runTime.timeName(),
            mesh,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh
);

volSymmTensorField b
(
        IOobject
        (
            "b",
            runTime.timeName(),
            mesh,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh
);

volScalarField d
(
    IOobject
    (
        "d",
        runTime.timeName(),
        mesh,
        IOobject::MUST_READ,
        IOobject::AUTO_WRITE
    ),
    mesh
);

#include "createPhi.H"

label pRefCell = 0;
scalar pRefValue = 0.0;
setRefCell(p, mesh.solutionDict().subDict("SIMPLE"), pRefCell, pRefValue);
mesh.setFluxRequired(p.name());

#include "createMRF.H"
#include "createFvOptions.H"

// Create matrix solver
#include "createSolver.H" 

// Create constitutive equation
constitutiveModel constEq(U, phi);
 
IOdictionary cttProperties
(
    IOobject
    (
        "constitutiveProperties",
        runTime.constant(),
        mesh,
        IOobject::MUST_READ_IF_MODIFIED,
        IOobject::NO_WRITE,
        false
    )
);
   
bool   sPS = cttProperties.subDict("passiveScalarProperties").lookupOrDefault<Switch>("solvePassiveScalar", false);


dimensionedScalar L2 = cttProperties.subDict("parameters").lookup("L2");

dimensionedScalar lambda = cttProperties.subDict("parameters").lookup("lambda");

dimensionedScalar rho = cttProperties.subDict("parameters").lookup("rho");

dimensionedScalar etaS = cttProperties.subDict("parameters").lookup("etaS");

dimensionedScalar etaP = cttProperties.subDict("parameters").lookup("etaP");

dimensionedScalar k = cttProperties.subDict("parameters").lookup("k");



volScalarField lck
(
    IOobject
    (
        "lck",
        runTime.timeName(),
        mesh,
        IOobject::NO_READ,
        IOobject::AUTO_WRITE
    ),
    1 - (tr(b.T() & b) / L2)
);

autoPtr<volScalarField>  C 
(
  sPS != true
  ? 
  NULL
  :
  new volScalarField
  (
    IOobject
    (
      "C",
      runTime.timeName(),
      mesh,
      IOobject::MUST_READ,
      IOobject::AUTO_WRITE
    ),
    mesh
 )
);

   
